@@ -1,7 +1,7 @@
 // qtractor.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -554,13 +554,6 @@ static bool update_palette ( QPalette& pal, const QString& sCustomColorTheme )
 // main - The main program trunk.
 //
 
-#if QT_VERSION >= 0x050100
-#ifdef CONFIG_LV2_UI_GTK2
-#undef signals // Collides with GTK symbology
-#include <gtk/gtk.h>
-#endif	// CONFIG_LV2_UI_GTK2
-#endif
-
 int main ( int argc, char **argv )
 {
 	Q_INIT_RESOURCE(qtractor);
@@ -588,13 +581,6 @@ int main ( int argc, char **argv )
 		return 2;
 	}
 
-#if QT_VERSION >= 0x050100
-#ifdef CONFIG_LV2_UI_GTK2
-	// Initialize GTK+ framework (LV2 plug-in UI GTK2 support)...
-	gtk_init(NULL, NULL);
-#endif	// CONFIG_LV2_UI_GTK2
-#endif
-
 	// Special style paths...
 	if (QDir(CONFIG_PLUGINSDIR).exists())
 		app.addLibraryPath(CONFIG_PLUGINSDIR);
@@ -659,3 +645,4 @@ int main ( int argc, char **argv )
 
 
 // end of qtractor.cpp
+
