@@ -56,6 +56,8 @@ public:
 		m_sFilename = pAudioClip->filename();;
 		m_iClipOffset = pAudioClip->clipOffset();
 		m_iClipLength = pAudioClip->clipLength();
+		m_fClipGain = pAudioClip->clipGain();
+		m_fClipPanning = pAudioClip->clipPanning();
 		m_fTimeStretch = pAudioClip->timeStretch();
 		m_fPitchShift = pAudioClip->pitchShift();
 		m_iOverlap = pAudioClip->overlap();
@@ -70,6 +72,10 @@ public:
 		{ return m_iClipOffset; }
 	unsigned long clipLength() const
 		{ return m_iClipLength; }
+	float clipGain() const
+		{ return m_fClipGain; }
+	float clipPanning() const
+		{ return m_fClipPanning; }
 	float timeStretch() const
 		{ return m_fTimeStretch; }
 	float pitchShift() const
@@ -84,6 +90,8 @@ public:
 			&& m_sFilename    == other.filename()
 			&& m_iClipOffset  == other.clipOffset()
 			&& m_iClipLength  == other.clipLength()
+			&& m_fClipGain    == other.clipGain()
+			&& m_fClipPanning == other.clipPanning()
 			&& m_fTimeStretch == other.timeStretch()
 			&& m_fPitchShift  == other.pitchShift()
 			&& m_iOverlap     == other.overlap();
@@ -96,6 +104,8 @@ private:
 	QString        m_sFilename;
 	unsigned long  m_iClipOffset;
 	unsigned long  m_iClipLength;
+	float          m_fClipGain;
+	float          m_fClipPanning;
 	float          m_fTimeStretch;
 	float          m_fPitchShift;
 	unsigned int   m_iOverlap;
@@ -108,8 +118,10 @@ uint qHash ( const qtractorAudioClip::Key& key )
 		 ^ qHash(key.filename())
 		 ^ qHash(key.clipOffset())
 		 ^ qHash(key.clipLength())
-		 ^ qHash(long(100.0f * key.timeStretch()))
-		 ^ qHash(long(100.0f * key.pitchShift()))
+		 ^ qHash(long(1000.0f * key.clipGain()))
+		 ^ qHash(long(1000.0f * key.clipPanning()))
+		 ^ qHash(long(1000.0f * key.timeStretch()))
+		 ^ qHash(long(1000.0f * key.pitchShift()))
 		 ^ qHash(key.overlap());
 }
 
@@ -136,6 +148,8 @@ qtractorAudioClip::qtractorAudioClip ( qtractorTrack *pTrack )
 	m_bWsolaQuickSeek = qtractorAudioBuffer::isDefaultWsolaQuickSeek();
 
 	m_iOverlap = 0;
+
+	m_pFractGains = NULL;
 }
 
 // Copy constructor.
@@ -154,9 +168,12 @@ qtractorAudioClip::qtractorAudioClip ( const qtractorAudioClip& clip )
 
 	m_iOverlap = clip.overlap();
 
+	m_pFractGains = NULL;
+
 	setFilename(clip.filename());
-	setClipGain(clip.clipGain());
 	setClipName(clip.clipName());
+	setClipGain(clip.clipGain());
+	setClipPanning(clip.clipPanning());
 
 	// Clone the audio peak, if any...
 	if (clip.m_pPeak)
@@ -174,60 +191,6 @@ qtractorAudioClip::~qtractorAudioClip (void)
 }
 
 
-// Time-stretch factor.
-void qtractorAudioClip::setTimeStretch ( float fTimeStretch )
-{
-	m_fTimeStretch = fTimeStretch;
-}
-
-float qtractorAudioClip::timeStretch (void) const
-{
-	return m_fTimeStretch;
-}
-
-
-// Pitch-shift factor.
-void qtractorAudioClip::setPitchShift ( float fPitchShift )
-{
-	m_fPitchShift = fPitchShift;
-}
-
-float qtractorAudioClip::pitchShift (void) const
-{
-	return m_fPitchShift;
-}
-
-
-// WSOLA time-stretch modes (local options).
-void qtractorAudioClip::setWsolaTimeStretch ( bool bWsolaTimeStretch )
-{
-	m_bWsolaTimeStretch = bWsolaTimeStretch;
-}
-
-bool qtractorAudioClip::isWsolaTimeStretch (void) const
-{
-	return m_bWsolaTimeStretch;
-}
-
-
-void qtractorAudioClip::setWsolaQuickSeek ( bool bWsolaQuickSeek )
-{
-	m_bWsolaQuickSeek = bWsolaQuickSeek;
-}
-
-bool qtractorAudioClip::isWsolaQuickSeek (void) const
-{
-	return m_bWsolaQuickSeek;
-}
-
-
-// Alternate overlap tag.
-unsigned int qtractorAudioClip::overlap (void) const
-{
-	return m_iOverlap;
-}
-
-
 // Alternating overlap test.
 bool qtractorAudioClip::isOverlap ( unsigned int iOverlapSize ) const
 {
@@ -325,6 +288,8 @@ bool qtractorAudioClip::openAudioFile ( const QString& sFilename, int iMode )
 							sFilename, pBuff->timeStretch());
 					}
 				}
+				// Gain/panning fractionalizer(tm)...
+				updateFractGains(pBuff);
 				// Clip name should be clear about it all.
 				if (clipName().isEmpty())
 					setClipName(shortClipName(QFileInfo(filename()).baseName()));
@@ -341,6 +306,8 @@ bool qtractorAudioClip::openAudioFile ( const QString& sFilename, int iMode )
 
 	pBuff->setOffset(clipOffset());
 	pBuff->setLength(clipLength());
+	pBuff->setGain(clipGain());
+	pBuff->setPanning(clipPanning());
 	pBuff->setTimeStretch(m_fTimeStretch);
 	pBuff->setPitchShift(m_fPitchShift);
 	pBuff->setWsolaTimeStretch(m_bWsolaTimeStretch);
@@ -352,6 +319,9 @@ bool qtractorAudioClip::openAudioFile ( const QString& sFilename, int iMode )
 		return false;
 	}
 
+	// Gain/panning fractionalizer(tm)...
+	updateFractGains(pBuff);
+
 	// Default clip length will be the whole file length.
 	if (clipLength() == 0)
 		setClipLength(pBuff->length() - pBuff->offset());
@@ -407,6 +377,11 @@ void qtractorAudioClip::closeAudioFile (void)
 		delete m_pKey;
 		m_pKey = NULL;
 	}
+
+	if (m_pFractGains) {
+		delete [] m_pFractGains;
+		m_pFractGains = NULL;
+	}
 }
 
 
@@ -505,6 +480,30 @@ void qtractorAudioClip::clearHashTable (void)
 }
 
 
+// Gain/panning fractionalizer(tm)...
+void qtractorAudioClip::updateFractGains ( qtractorAudioBuffer *pBuff )
+{
+	if (m_pFractGains) {
+		delete [] m_pFractGains;
+		m_pFractGains = NULL;
+	}
+
+	const unsigned short iChannels = pBuff->channels();
+	m_pFractGains = new FractGain [iChannels];
+	for (unsigned short i = 0; i < iChannels; ++i) {
+		FractGain& fractGain = m_pFractGains[i];
+		fractGain.num = 1;
+		fractGain.den = 8;
+		float fGain = clipGain() * pBuff->channelGain(i);
+		while(fGain != int(fGain) && fractGain.den < 20) {
+			fractGain.den += 2;
+			fGain *= 4.0f;
+		}
+		fractGain.num = int(fGain);
+	}
+}
+
+
 // Direct write method.
 void qtractorAudioClip::write ( float **ppBuffer,
 	unsigned int iFrames, unsigned short iChannels, unsigned int iOffset )
@@ -590,7 +589,8 @@ void qtractorAudioClip::close (void)
 // Audio clip (re)open method.
 void qtractorAudioClip::open (void)
 {
-	openAudioFile(filename());
+	const QString sFilename(filename());
+	openAudioFile(sFilename);
 }
 
 
@@ -626,7 +626,7 @@ void qtractorAudioClip::process (
 				iOffset,
 				pAudioBus->channels(),
 				iClipStart - iFrameStart,
-				gain(iOffset));
+				fadeInOutGain(iOffset));
 		}
 	} else {
 		if (pBuff->inSync(iFrameStart - iClipStart, iOffset)) {
@@ -635,7 +635,7 @@ void qtractorAudioClip::process (
 				(iFrameEnd < iClipEnd ? iFrameEnd : iClipEnd) - iFrameStart,
 				pAudioBus->channels(),
 				0,
-				gain(iOffset));
+				fadeInOutGain(iOffset));
 		}
 	}
 }
@@ -695,7 +695,6 @@ void qtractorAudioClip::draw (
 	// Draw peak chart...
 	const int h1 = (clipRect.height() / iChannels);
 	const int h2 = (h1 >> 1);
-	const int h2gain = (h2 * m_fractGain.num);
 
 	int x, y, ymax, ymin, yrms;
 
@@ -705,9 +704,11 @@ void qtractorAudioClip::draw (
 		x = clipRect.x() + (n * clipRect.width()) / n2;
 		y = clipRect.y() + h2;
 		for (k = 0; k < iChannels; ++k) {
-			ymax = (h2gain * pPeakFrames->max) >> m_fractGain.den;
-			ymin = (h2gain * pPeakFrames->min) >> m_fractGain.den;
-			yrms = (h2gain * pPeakFrames->rms) >> m_fractGain.den;
+			const FractGain& fractGain = m_pFractGains[k];
+			const int h2gain = (h2 * fractGain.num);
+			ymax = (h2gain * pPeakFrames->max) >> fractGain.den;
+			ymin = (h2gain * pPeakFrames->min) >> fractGain.den;
+			yrms = (h2gain * pPeakFrames->rms) >> fractGain.den;
 			pPolyMax[k]->setPoint(n, x, y - ymax);
 			pPolyMax[k]->setPoint(iPolyPoints - n - 1, x, y + ymin);
 			pPolyRms[k]->setPoint(n, x, y - yrms);
@@ -746,10 +747,14 @@ QString qtractorAudioClip::toolTip (void) const
 			sToolTip += QObject::tr("\nAudio:\t%1 channels, %2 Hz")
 				.arg(pFile->channels())
 				.arg(pFile->sampleRate());
-			float fGain = clipGain();
+			const float fGain = clipGain();
 			if (fGain < 0.999f || fGain > 1.001f)
 				sToolTip += QObject::tr(" (%1 dB)")
 					.arg(20.0f * ::log10f(fGain), 0, 'g', 2);
+			const float fPanning = clipPanning();
+			if (fPanning < -0.001f || fPanning > +0.001f)
+				sToolTip += QObject::tr(" (%1 pan)")
+					.arg(fPanning, 0, 'g', 1);
 			if (pBuff->isTimeStretch())
 				sToolTip += QObject::tr("\n\t(%1% time stretch)")
 					.arg(100.0f * pBuff->timeStretch(), 0, 'g', 3);
@@ -863,7 +868,6 @@ bool qtractorAudioClip::clipExport ( ClipExport pfnClipExport, void *pvArg,
 		::memset(ppFrames[i], 0, iFrames * sizeof(float));
 	}
 
-	const float fGain = clipGain();
 	unsigned long iFrameStart = 0;
 	while (iFrameStart < iLength) {
 		pBuff->syncExport();
@@ -872,6 +876,7 @@ bool qtractorAudioClip::clipExport ( ClipExport pfnClipExport, void *pvArg,
 			if (nread < 1)
 				break;
 			for (i = 0; i < iChannels; ++i) {
+				const float fGain = clipGain() * pBuff->channelGain(i);
 				float *pFrames = ppFrames[i];
 				for (int n = 0; n < nread; ++n)
 					*pFrames++ *= fGain;
