@@ -169,7 +169,7 @@ public:
 	~qtractorAudioExportBuffer()
 	{
 		for (unsigned short i = 0; i < m_iChannels; ++i)
-			delete m_ppBuffer[i];
+			delete [] m_ppBuffer[i];
 
 		delete [] m_ppBuffer;
 	}
@@ -421,18 +421,18 @@ qtractorAudioEngine::qtractorAudioEngine ( qtractorSession *pSession )
 	m_bExportDone  = true;
 
 	// Audio metronome stuff.
-	m_bMetronome      = false;
-	m_bMetroBus       = false;
-	m_pMetroBus       = NULL;
+	m_bMetronome        = false;
+	m_bMetroBus         = false;
+	m_pMetroBus         = NULL;
 	m_bMetroAutoConnect = true;
-	m_pMetroBarBuff   = NULL;
-	m_pMetroBeatBuff  = NULL;
-	m_fMetroBarGain   = 1.0f;
-	m_fMetroBeatGain  = 1.0f;
-	m_iMetroOffset    = 0;
-	m_iMetroBeatStart = 0;
-	m_iMetroBeat      = 0;
-	m_bMetroEnabled   = false;
+	m_pMetroBarBuff     = NULL;
+	m_fMetroBarGain     = 1.0f;
+	m_pMetroBeatBuff    = NULL;
+	m_fMetroBeatGain    = 1.0f;
+	m_iMetroOffset      = 0;
+	m_iMetroBeatStart   = 0;
+	m_iMetroBeat        = 0;
+	m_bMetroEnabled     = false;
 
 	// Audition/pre-listening player stuff.
 	ATOMIC_SET(&m_playerLock, 0);
@@ -449,6 +449,9 @@ qtractorAudioEngine::qtractorAudioEngine ( qtractorSession *pSession )
 	// JACK timebase mode control.
 	m_bTimebase = true;
 	m_iTimebase = 0;
+
+	// JACK Timebase sync flag.
+	m_iTimebaseHold = 0;
 }
 
 
@@ -876,7 +879,7 @@ int qtractorAudioEngine::process ( unsigned int nframes )
 
 #ifdef CONFIG_LV2
 #ifdef CONFIG_LV2_TIME
-	qtractorLv2Plugin::updateTime(m_pJackClient);
+	qtractorLv2Plugin::updateTime(this);
 #endif
 #endif
 
@@ -954,21 +957,17 @@ int qtractorAudioEngine::process ( unsigned int nframes )
 		qtractorTimeScale::Cursor& cursor = pSession->timeScale()->cursor();
 		qtractorTimeScale::Node *pNode = cursor.seekFrame(iFrameStart);
 		qtractorAudioBuffer *pMetroBuff = NULL;
-		float fMetroGain = 1.0f;
-		if (pNode->beatIsBar(m_iMetroBeat)) {
+		if (pNode->beatIsBar(m_iMetroBeat))
 			pMetroBuff = m_pMetroBarBuff;
-			fMetroGain = m_fMetroBarGain;
-		} else {
+		else
 			pMetroBuff = m_pMetroBeatBuff;
-			fMetroGain = m_fMetroBeatGain;
-		}
 		if (iFrameStart < m_iMetroBeatStart) {
 			pMetroBuff->readMix(m_pMetroBus->out(),
 				iFrameEnd - m_iMetroBeatStart, m_pMetroBus->channels(),
-				m_iMetroBeatStart - iFrameStart, fMetroGain);
+				m_iMetroBeatStart - iFrameStart, 1.0f);
 		} else if (iFrameStart < m_iMetroBeatStart + pMetroBuff->length()) {
 			pMetroBuff->readMix(m_pMetroBus->out(),
-				nframes, m_pMetroBus->channels(), 0, fMetroGain);
+				nframes, m_pMetroBus->channels(), 0, 1.0f);
 		} else {
 			m_iMetroBeatStart = metro_offset(pNode->frameFromBeat(++m_iMetroBeat));
 			pMetroBuff->reset(false);
@@ -1086,7 +1085,7 @@ void qtractorAudioEngine::process_export ( unsigned int nframes )
 		// Force/sync every audio clip approaching...
 	#ifdef CONFIG_LV2
 	#ifdef CONFIG_LV2_TIME
-		qtractorLv2Plugin::updateTime(m_pJackClient);
+		qtractorLv2Plugin::updateTime(this);
 	#endif
 	#endif
 		// MIDI plugin manager processing...
@@ -1190,7 +1189,10 @@ void qtractorAudioEngine::timebase ( jack_position_t *pPos, int iNewPos )
 	pPos->beat_type        = float(1 << pNode->beatDivisor);
 
 	// Tell that we've been here...
-	if (iNewPos) ++m_iTimebase;
+	if (iNewPos) {
+		++m_iTimebase;
+		m_iTimebaseHold = 0;
+	}
 }
 
 
@@ -1446,6 +1448,11 @@ bool qtractorAudioEngine::fileExport (
 
 	while (m_bExporting && !m_bExportDone) {
 		qtractorSession::stabilize(200);
+	#ifdef CONFIG_LV2
+	#ifdef CONFIG_LV2_TIME
+		qtractorLv2Plugin::updateTimePost();
+	#endif
+	#endif
 		::nanosleep(&ts, NULL); // Ain't that enough?
 		pProgressBar->setValue(pSession->playHead());
 	}
@@ -1701,9 +1708,11 @@ bool qtractorAudioEngine::openMetroBus (void)
 
 	// We got it...
 	m_pMetroBarBuff = new qtractorAudioBuffer(m_pSyncThread, iChannels);
+	m_pMetroBarBuff->setGain(m_fMetroBarGain);
 	m_pMetroBarBuff->open(m_sMetroBarFilename);
 
 	m_pMetroBeatBuff = new qtractorAudioBuffer(m_pSyncThread, iChannels);
+	m_pMetroBeatBuff->setGain(m_fMetroBeatGain);
 	m_pMetroBeatBuff->open(m_sMetroBeatFilename);
 
 	return true;
@@ -2044,6 +2053,22 @@ void qtractorAudioEngine::resetTimebase (void)
 }
 
 
+// JACK Timebase/transport sync flagging.
+void qtractorAudioEngine::resetTimebaseHold (void)
+{
+	if (m_bTimebase)
+		++m_iTimebaseHold;
+	else
+		m_iTimebaseHold = 0;
+}
+
+
+bool qtractorAudioEngine::isTimebaseHold (void) const
+{
+	return (m_iTimebaseHold > 0);
+}
+
+
 // Absolute number of frames elapsed since engine start.
 unsigned long qtractorAudioEngine::jackFrameTime (void) const
 {
@@ -2100,21 +2125,17 @@ qtractorAudioBus::qtractorAudioBus (
 	if ((busMode & qtractorBus::Input) && !(busMode & qtractorBus::Ex)) {
 		m_pIAudioMonitor = new qtractorAudioMonitor(iChannels);
 		m_pIPluginList   = createPluginList(qtractorPluginList::AudioInBus);
-		m_pICurveFile    = new qtractorCurveFile(m_pIPluginList->curveList());
 	} else {
 		m_pIAudioMonitor = NULL;
 		m_pIPluginList   = NULL;
-		m_pICurveFile    = NULL;
 	}
 
 	if ((busMode & qtractorBus::Output) && !(busMode & qtractorBus::Ex)) {
 		m_pOAudioMonitor = new qtractorAudioMonitor(iChannels);
 		m_pOPluginList   = createPluginList(qtractorPluginList::AudioOutBus);
-		m_pOCurveFile    = new qtractorCurveFile(m_pOPluginList->curveList());
 	} else {
 		m_pOAudioMonitor = NULL;
 		m_pOPluginList   = NULL;
-		m_pOCurveFile    = NULL;
 	}
 
 	m_bAutoConnect = false;
@@ -2149,11 +2170,6 @@ qtractorAudioBus::~qtractorAudioBus (void)
 	if (m_pOAudioMonitor)
 		delete m_pOAudioMonitor;
 
-	if (m_pICurveFile)
-		delete m_pICurveFile;
-	if (m_pOCurveFile)
-		delete m_pOCurveFile;
-
 	if (m_pIPluginList)
 		delete m_pIPluginList;
 	if (m_pOPluginList)
@@ -2419,17 +2435,11 @@ void qtractorAudioBus::updateBusMode (void)
 			m_pIAudioMonitor = new qtractorAudioMonitor(m_iChannels);
 		if (m_pIPluginList == NULL)
 			m_pIPluginList = createPluginList(qtractorPluginList::AudioInBus);
-		if (m_pICurveFile == NULL)
-			m_pICurveFile = new qtractorCurveFile(m_pIPluginList->curveList());
 	} else {
 		if (m_pIAudioMonitor) {
 			delete m_pIAudioMonitor;
 			m_pIAudioMonitor = NULL;
 		}
-		if (m_pICurveFile) {
-			delete m_pICurveFile;
-			m_pICurveFile = NULL;
-		}
 		if (m_pIPluginList) {
 			delete m_pIPluginList;
 			m_pIPluginList = NULL;
@@ -2442,17 +2452,11 @@ void qtractorAudioBus::updateBusMode (void)
 			m_pOAudioMonitor = new qtractorAudioMonitor(m_iChannels);
 		if (m_pOPluginList == NULL)
 			m_pOPluginList = createPluginList(qtractorPluginList::AudioOutBus);
-		if (m_pOCurveFile == NULL)
-			m_pOCurveFile = new qtractorCurveFile(m_pOPluginList->curveList());
 	} else {
 		if (m_pOAudioMonitor) {
 			delete m_pOAudioMonitor;
 			m_pOAudioMonitor = NULL;
 		}
-		if (m_pOCurveFile) {
-			delete m_pOCurveFile;
-			m_pOCurveFile = NULL;
-		}
 		if (m_pOPluginList) {
 			delete m_pOPluginList;
 			m_pOPluginList = NULL;
@@ -2657,30 +2661,6 @@ qtractorPluginList *qtractorAudioBus::pluginList_out (void) const
 }
 
 
-// Automation curve list accessors.
-qtractorCurveList *qtractorAudioBus::curveList_in (void) const
-{
-	return (m_pIPluginList ? m_pIPluginList->curveList() : NULL);
-}
-
-qtractorCurveList *qtractorAudioBus::curveList_out (void) const
-{
-	return (m_pOPluginList ? m_pOPluginList->curveList() : NULL);
-}
-
-
-// Automation curve serializer accessors.
-qtractorCurveFile *qtractorAudioBus::curveFile_in (void) const
-{
-	return m_pICurveFile;
-}
-
-qtractorCurveFile *qtractorAudioBus::curveFile_out (void) const
-{
-	return m_pOCurveFile;
-}
-
-
 // Audio I/O port latency accessors.
 unsigned int qtractorAudioBus::latency_in (void) const
 {
@@ -2932,9 +2912,6 @@ bool qtractorAudioBus::loadElement (
 					eProp.text().toFloat());
 		} else if (eProp.tagName() == "input-controllers") {
 			qtractorAudioBus::loadControllers(&eProp, qtractorBus::Input);
-		} else if (eProp.tagName() == "input-curve-file") {
-			qtractorAudioBus::loadCurveFile(&eProp, qtractorBus::Input,
-				qtractorAudioBus::curveFile_in());
 		} else if (eProp.tagName() == "input-plugins") {
 			if (qtractorAudioBus::pluginList_in())
 				qtractorAudioBus::pluginList_in()->loadElement(
@@ -2952,9 +2929,6 @@ bool qtractorAudioBus::loadElement (
 					eProp.text().toFloat());
 		} else if (eProp.tagName() == "output-controllers") {
 			qtractorAudioBus::loadControllers(&eProp, qtractorBus::Output);
-		} else if (eProp.tagName() == "output-curve-file") {
-			qtractorAudioBus::loadCurveFile(&eProp, qtractorBus::Output,
-				qtractorAudioBus::curveFile_out());
 		} else if (eProp.tagName() == "output-plugins") {
 			if (qtractorAudioBus::pluginList_out())
 				qtractorAudioBus::pluginList_out()->loadElement(
@@ -3004,16 +2978,6 @@ bool qtractorAudioBus::saveElement (
 		qtractorAudioBus::saveControllers(pDocument,
 			&eInputControllers, qtractorBus::Input);
 		pElement->appendChild(eInputControllers);
-		// Save input bus automation curves...
-		qtractorCurveList *pInputCurveList = qtractorAudioBus::curveList_in();
-		if (pInputCurveList && !pInputCurveList->isEmpty()) {
-			qtractorCurveFile cfile(pInputCurveList);
-			QDomElement eInputCurveFile
-				= pDocument->document()->createElement("input-curve-file");
-			qtractorAudioBus::saveCurveFile(pDocument,
-				&eInputCurveFile, qtractorBus::Input, &cfile);
-			pElement->appendChild(eInputCurveFile);
-		}
 		// Save input bus plugins...
 		if (qtractorAudioBus::pluginList_in()) {
 			QDomElement eInputPlugins
@@ -3046,16 +3010,6 @@ bool qtractorAudioBus::saveElement (
 		qtractorAudioBus::saveControllers(pDocument,
 			&eOutputControllers, qtractorBus::Output);
 		pElement->appendChild(eOutputControllers);
-		// Save output bus automation curves...
-		qtractorCurveList *pOutputCurveList = qtractorAudioBus::curveList_out();
-		if (pOutputCurveList && !pOutputCurveList->isEmpty()) {
-			qtractorCurveFile cfile(pOutputCurveList);
-			QDomElement eOutputCurveFile
-				= pDocument->document()->createElement("output-curve-file");
-			qtractorAudioBus::saveCurveFile(pDocument,
-				&eOutputCurveFile, qtractorBus::Output, &cfile);
-			pElement->appendChild(eOutputCurveFile);
-		}
 		// Save output bus plugins...
 		if (qtractorAudioBus::pluginList_out()) {
 			QDomElement eOutputPlugins
