@@ -1,7 +1,7 @@
 // qtractorAudioFile.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,8 +28,6 @@
 #include <QFileInfo>
 #include <QRegExp>
 
-#include <stdlib.h>
-
 
 //----------------------------------------------------------------------
 // class qtractorAudioFileFactory -- Audio file factory (singleton).
@@ -38,28 +36,10 @@
 // Initialize singleton instance pointer.
 qtractorAudioFileFactory *qtractorAudioFileFactory::g_pInstance = NULL;
 
-
 // Singleton instance accessor.
-qtractorAudioFileFactory& qtractorAudioFileFactory::getInstance (void)
+qtractorAudioFileFactory *qtractorAudioFileFactory::getInstance (void)
 {
-	// Create the singleton instance, if not already...
-	if (g_pInstance == NULL) {
-		g_pInstance = new qtractorAudioFileFactory();
-		::atexit(Destroy);
-	}
-
-	return *g_pInstance;
-}
-
-
-// Singleton instance destroyer.
-void qtractorAudioFileFactory::Destroy (void)
-{
-	// OK. We're done with ourselves.
-	if (g_pInstance) {
-		delete g_pInstance;
-		g_pInstance = NULL;
-	}
+	return g_pInstance;
 }
 
 
@@ -99,7 +79,7 @@ qtractorAudioFileFactory::qtractorAudioFileFactory (void)
 			// specially regarding filename extensions...
 			if (sExt.length() > 3) {
 				sExt = sExt.left(3);
-				if (m_types.find(sExt) == m_types.end()) {
+				if (m_types.constFind(sExt) == m_types.constEnd()) {
 					sExts = sExtMask.arg(sExt) + ' ' + sExts;
 					m_types[sExt] = pFormat;
 				}
@@ -149,20 +129,26 @@ qtractorAudioFileFactory::qtractorAudioFileFactory (void)
 		const QString& sExt = iter.key();
 		if (rx.exactMatch(sExt))
 			exts.append(sExtMask.arg(sExt));
+		m_exts.append(sExt);
 	}
 	m_filters.prepend(QObject::tr("Audio files (%1)").arg(exts.join(" ")));
 	m_filters.append(QObject::tr("All files (*.*)"));
+
+	g_pInstance = this;
 }
 
 
 // Destructor.
 qtractorAudioFileFactory::~qtractorAudioFileFactory (void)
 {
+	g_pInstance = NULL;
+
 	qDeleteAll(m_formats);
 
 	m_formats.clear();
 	m_filters.clear();
 	m_types.clear();
+	m_exts.clear();
 }
 
 
@@ -171,7 +157,7 @@ qtractorAudioFile *qtractorAudioFileFactory::createAudioFile (
 	const QString& sFilename, unsigned short iChannels,
 	unsigned int iSampleRate, unsigned int iBufferSize )
 {
-	return getInstance().newAudioFile(
+	return g_pInstance->newAudioFile(
 		sFilename, iChannels, iSampleRate, iBufferSize);
 }
 
@@ -179,7 +165,8 @@ qtractorAudioFile *qtractorAudioFileFactory::createAudioFile (
 	FileType type, unsigned short iChannels,
 	unsigned int iSampleRate, unsigned int iBufferSize )
 {
-	return getInstance().newAudioFile(type, iChannels, iSampleRate, iBufferSize);
+	return g_pInstance->newAudioFile(
+		type, iChannels, iSampleRate, iBufferSize);
 }
 
 
@@ -188,15 +175,15 @@ qtractorAudioFile *qtractorAudioFileFactory::newAudioFile (
 	const QString& sFilename, unsigned short iChannels,
 	unsigned int iSampleRate, unsigned int iBufferSize )
 {
-	const QString sExt = QFileInfo(sFilename).suffix().toLower();
-	
-	FileTypes::ConstIterator iter = m_types.constFind(sExt);
+	const QString& sExt = QFileInfo(sFilename).suffix().toLower();
+	const FileTypes::ConstIterator& iter = m_types.constFind(sExt);
 	if (iter == m_types.constEnd())
 		return NULL;
 
 	return newAudioFile(iter.value()->type, iChannels, iSampleRate, iBufferSize);
 }
 
+
 qtractorAudioFile *qtractorAudioFileFactory::newAudioFile (
 	FileType type, unsigned short iChannels,
 	unsigned int iSampleRate, unsigned int iBufferSize )
@@ -216,43 +203,62 @@ qtractorAudioFile *qtractorAudioFileFactory::newAudioFile (
 
 const qtractorAudioFileFactory::FileFormats& qtractorAudioFileFactory::formats (void)
 {
-	return getInstance().m_formats;
+	return g_pInstance->m_formats;
+}
+
+
+const qtractorAudioFileFactory::FileTypes& qtractorAudioFileFactory::types (void)
+{
+	return g_pInstance->m_types;
+}
+
+
+// The supported file types/names format lists.
+const QStringList& qtractorAudioFileFactory::filters (void)
+{
+	return g_pInstance->m_filters;
+}
+
+
+const QStringList& qtractorAudioFileFactory::exts (void)
+{
+	return g_pInstance->m_exts;
 }
 
 
 // Retrieve supported filters (suitable for QFileDialog usage).
-QString qtractorAudioFileFactory::filters (void)
+QString qtractorAudioFileFactory::filter (void)
 {
-	return getInstance().m_filters.join(";;");
+	return g_pInstance->m_filters.join(";;");
 }
 
 
 // Default audio file format accessors
 // (specific to capture/recording)
-void qtractorAudioFileFactory::setDefaultType(const QString& sExt, int iType,
-	int iFormat, int iQuality )
+void qtractorAudioFileFactory::setDefaultType (
+	const QString& sExt, int iType, int iFormat, int iQuality )
 {
 	// Search for type-format first...
 	int iDefaultFormat = 0;
-	QListIterator<FileFormat *> iter(getInstance().m_formats);
+	QListIterator<FileFormat *> iter(g_pInstance->m_formats);
 	while (iter.hasNext()) {
 		FileFormat *pFormat = iter.next();
 		if (sExt == pFormat->ext && (iType == 0 || iType == pFormat->data)) {
-			getInstance().m_pDefaultFormat = pFormat;
+			g_pInstance->m_pDefaultFormat = pFormat;
 			iDefaultFormat = format(pFormat, iFormat);
 			break;
 		}
 	}
 
 	// Rest is not so obviously trivial...
-	getInstance().m_iDefaultFormat  = iDefaultFormat;
-	getInstance().m_iDefaultQuality = iQuality;
+	g_pInstance->m_iDefaultFormat  = iDefaultFormat;
+	g_pInstance->m_iDefaultQuality = iQuality;
 }
 
 
 QString qtractorAudioFileFactory::defaultExt (void)
 {
-	FileFormat *pFormat = getInstance().m_pDefaultFormat;
+	FileFormat *pFormat = g_pInstance->m_pDefaultFormat;
 	if (pFormat)
 		return pFormat->ext;
 
@@ -263,10 +269,11 @@ QString qtractorAudioFileFactory::defaultExt (void)
 #endif
 }
 
+
 int qtractorAudioFileFactory::defaultFormat (void)
 {
-	int  iDefaultFormat = getInstance().m_iDefaultFormat;
-	FileFormat *pFormat = getInstance().m_pDefaultFormat;
+	int  iDefaultFormat = g_pInstance->m_iDefaultFormat;
+	FileFormat *pFormat = g_pInstance->m_pDefaultFormat;
 	if (pFormat)
 		iDefaultFormat |= pFormat->data;
 #ifndef CONFIG_LIBVORBIS_0
@@ -280,7 +287,7 @@ int qtractorAudioFileFactory::defaultFormat (void)
 
 int qtractorAudioFileFactory::defaultQuality (void)
 {
-	return getInstance().m_iDefaultQuality;
+	return g_pInstance->m_iDefaultQuality;
 }
 
 
