@@ -1,7 +1,7 @@
 // qtractorAudioMeter.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -27,7 +27,6 @@
 
 // Forward declarations.
 class qtractorAudioMeter;
-class qtractorAudioMeterValue;
 class qtractorAudioMonitor;
 
 class QResizeEvent;
@@ -39,13 +38,10 @@ class QPaintEvent;
 
 class qtractorAudioMeterScale : public qtractorMeterScale
 {
-	Q_OBJECT
-
 public:
 
 	// Constructor.
-	qtractorAudioMeterScale(qtractorAudioMeter *pAudioMeter,
-		QWidget *pParent = 0);
+	qtractorAudioMeterScale(qtractorAudioMeter *pAudioMeter);
 
 protected:
 
@@ -57,21 +53,16 @@ protected:
 //----------------------------------------------------------------------------
 // qtractorAudioMeterValue -- Audio meter bridge value widget.
 
-class qtractorAudioMeterValue : public QWidget
+class qtractorAudioMeterValue : public qtractorMeterValue
 {
-	Q_OBJECT
-
 public:
 
 	// Constructor.
-	qtractorAudioMeterValue(qtractorAudioMeter *pAudioMeter,
-		unsigned short iChannel, QWidget *pParent = 0);
-
-	// Reset peak holder.
-	void peakReset() { m_iPeak = 0; }
+	qtractorAudioMeterValue(
+		qtractorAudioMeter *pAudioMeter, unsigned short iChannel);
 
 	// Value refreshment.
-	void refresh();
+	void refresh(unsigned long iStamp);
 
 protected:
 
@@ -82,8 +73,7 @@ protected:
 private:
 
 	// Local instance variables.
-	qtractorAudioMeter *m_pAudioMeter;
-	unsigned short      m_iChannel;
+	unsigned short m_iChannel;
 
 	// Running variables.
 	int   m_iValue;
@@ -95,18 +85,18 @@ private:
 };
 
 
+
 //----------------------------------------------------------------------------
 // qtractorAudioMeter -- Audio meter bridge slot widget.
 
 class qtractorAudioMeter : public qtractorMeter
 {
-	Q_OBJECT
-
 public:
 
 	// Constructor.
-	qtractorAudioMeter(qtractorAudioMonitor *pAudioMonitor,
-		QWidget *pParent = 0);
+	qtractorAudioMeter(
+		qtractorAudioMonitor *pAudioMonitor, QWidget *pParent = 0);
+
 	// Default destructor.
 	~qtractorAudioMeter();
 
@@ -118,27 +108,13 @@ public:
 	void setAudioMonitor(qtractorAudioMonitor *pAudioMonitor);
 	qtractorAudioMonitor *audioMonitor() const;
 
-	// Local slider update methods.
-	void updatePanning();
-	void updateGain();
-
 	// Monitor reset.
 	void reset();
 
-	// Slot refreshment.
-	void refresh();
-
-	// Reset peak holder.
-	void peakReset();
-
 	// IEC scale accessors.
 	int iec_scale(float dB) const;
 	int iec_level(int iIndex) const;
 
-	// For faster scaling when drawing...
-	int scale(float fValue) const
-		{ return int(m_fScale * fValue); }
-
 #ifdef CONFIG_GRADIENT
 	const QPixmap& pixmap() const;
 	void updatePixmap();
@@ -169,18 +145,12 @@ protected:
 
 private:
 
-	// Local forward declarations.
-	class GainSliderInterface;
-	class GainSpinBoxInterface;
-
 	// Local instance variables.
 	qtractorAudioMonitor     *m_pAudioMonitor;
 	unsigned short            m_iChannels;
-	qtractorAudioMeterScale  *m_pAudioScale;
 	qtractorAudioMeterValue **m_ppAudioValues;
 
-	float  m_fScale;
-	int    m_levels[LevelCount];
+	int m_levels[LevelCount];
 
 #ifdef CONFIG_GRADIENT
 	QPixmap *m_pPixmap;
@@ -190,7 +160,50 @@ private:
 	static QColor g_currentColors[ColorCount];
 };
 
-	
+
+//----------------------------------------------------------------------------
+// qtractorAudioMixerMeter -- Audio mixer-strip meter bridge widget.
+
+class qtractorAudioMixerMeter : public qtractorMixerMeter
+{
+	Q_OBJECT
+
+public:
+
+	// Constructor.
+	qtractorAudioMixerMeter(
+		qtractorAudioMonitor *pAudioMonitor, QWidget *pParent = 0);
+
+	// Default destructor.
+	~qtractorAudioMixerMeter();
+
+	// Virtual monitor accessor.
+	void setMonitor(qtractorMonitor *pMonitor);
+	qtractorMonitor *monitor() const;
+
+	// Audio monitor accessor.
+	void setAudioMonitor(qtractorAudioMonitor *pAudioMonitor);
+	qtractorAudioMonitor *audioMonitor() const;
+
+	// Local slider update methods.
+	void updatePanning();
+	void updateGain();
+
+	// Monitor reset.
+	void reset();
+
+private:
+
+	// Local forward declarations.
+	class GainSliderInterface;
+	class GainSpinBoxInterface;
+
+	// Local instance variables.
+	qtractorAudioMeter       *m_pAudioMeter;
+	qtractorAudioMeterScale  *m_pAudioScale;
+};
+
+
 #endif  // __qtractorAudioMeter_h
 
 // end of qtractorAudioMeter.h
