@@ -1,7 +1,7 @@
 // qtractorAudioMonitor.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -162,8 +162,8 @@ static inline void std_process_meter (
 // Constructor.
 qtractorAudioMonitor::qtractorAudioMonitor ( unsigned short iChannels,
 	float fGain, float fPanning ) : qtractorMonitor(fGain, fPanning),
-	m_iChannels(0), m_pfValues(NULL), m_pfGains(NULL), m_pfPrevGains(NULL),
-	m_iProcessRamp(0)
+	m_iChannels(0), m_piStamps(NULL), m_pfValues(NULL), m_pfPrevValues(NULL),
+	m_pfGains(NULL), m_pfPrevGains(NULL), m_iProcessRamp(0)
 {
 	qtractorMonitor::gainSubject()->setMaxValue(2.0f);	// +6dB
 	qtractorMonitor::gainObserver()->setLogarithmic(true);
@@ -201,11 +201,21 @@ void qtractorAudioMonitor::setChannels ( unsigned short iChannels )
 		return;
 
 	// Delete old value holders...
+	if (m_piStamps) {
+		delete [] m_piStamps;
+		m_piStamps = NULL;
+	}
+
 	if (m_pfValues) {
 		delete [] m_pfValues;
 		m_pfValues = NULL;
 	}
 
+	if (m_pfPrevValues) {
+		delete [] m_pfPrevValues;
+		m_pfPrevValues = NULL;
+	}
+
 	// Delete old panning-gains holders...
 	if (m_pfGains) {
 		delete [] m_pfGains;
@@ -220,13 +230,18 @@ void qtractorAudioMonitor::setChannels ( unsigned short iChannels )
 	// Set new value holders...
 	m_iChannels = iChannels;
 	if (m_iChannels > 0) {
-        m_pfValues = new float [m_iChannels];
-        m_pfGains = new float [m_iChannels];
-        m_pfPrevGains = new float [m_iChannels];
-        for (unsigned short i = 0; i < m_iChannels; ++i)
-            m_pfValues[i] = m_pfGains[i] = m_pfPrevGains[i] = 0.0f;
-        // Initial population...
-        update();
+		m_piStamps = new unsigned long [m_iChannels];
+		m_pfValues = new float [m_iChannels];
+		m_pfPrevValues = new float [m_iChannels];
+		m_pfGains = new float [m_iChannels];
+		m_pfPrevGains = new float [m_iChannels];
+		for (unsigned short i = 0; i < m_iChannels; ++i) {
+			m_piStamps[i] = 0;
+			m_pfValues[i] = m_pfPrevValues[i] = 0.0f;
+			m_pfGains[i] = m_pfPrevGains[i] = 0.0f;
+		}
+		// Initial population...
+		update();
     }
 }
 
@@ -237,19 +252,27 @@ unsigned short qtractorAudioMonitor::channels (void) const
 
 
 // Value holder accessor.
-float qtractorAudioMonitor::value ( unsigned short iChannel ) const
+float qtractorAudioMonitor::value_stamp (
+	unsigned short iChannel, unsigned long iStamp ) const
 {
-	const float fValue = m_pfValues[iChannel];
-	m_pfValues[iChannel] = 0.0f;
-	return fValue;
+	if (m_piStamps[iChannel] != iStamp) {
+		m_piStamps[iChannel]  = iStamp;
+		m_pfPrevValues[iChannel] = m_pfValues[iChannel];
+		m_pfValues[iChannel]  = 0.0f;
+	}
+
+	return m_pfPrevValues[iChannel];
 }
 
 
 // Reset channel gain trackers.
 void qtractorAudioMonitor::reset (void)
 {
-	for (unsigned short i = 0; i < m_iChannels; ++i)
-		m_pfPrevGains[i] = m_pfValues[i] = 0.0f;
+	for (unsigned short i = 0; i < m_iChannels; ++i) {
+		m_piStamps[i] = 0;
+		m_pfValues[i] = m_pfPrevValues[i] = 0.0f;
+		m_pfPrevGains[i] = 0.0f;
+	}
 
 	++m_iProcessRamp;
 }
@@ -362,21 +385,21 @@ void qtractorAudioMonitor::update (void)
 
 	// (Re)compute equal-power stereo-panning gains...
 	if (fPan < 0.499f || fPan > 0.501f) {
-#ifdef QTRACTOR_MONITOR_PANNING_SQRT
+	#ifdef QTRACTOR_MONITOR_PANNING_SQRT
 		afGains[0] *= M_SQRT2 * ::sqrtf(1.0f - fPan);
 		afGains[1] *= M_SQRT2 * ::sqrtf(fPan);
-#else
+	#else
 		afGains[0] *= M_SQRT2 * ::cosf(fPan * M_PI_2);
 		afGains[1] *= M_SQRT2 * ::sinf(fPan * M_PI_2);
-#endif
+	#endif
     }
 
 	// Apply to multi-channel gain array (paired fashion)...
-	const unsigned short iChannels = (m_iChannels - (m_iChannels % 2));
+	const unsigned short k = (m_iChannels - (m_iChannels & 1));
 	unsigned short i = 0;
-	for ( ; i < iChannels; ++i) {
+	for ( ; i < k; ++i) {
 		m_pfPrevGains[i] = m_pfGains[i];
-		m_pfGains[i] = afGains[i % 2];
+		m_pfGains[i] = afGains[i & 1];
 	}
 	for ( ; i < m_iChannels; ++i) {
 		m_pfPrevGains[i] = m_pfGains[i];
