@@ -1,7 +1,7 @@
 // qtractorAudioMonitor.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,7 +44,7 @@ public:
 	unsigned short channels() const;
 
 	// Value holder accessor.
-	float value(unsigned short iChannel) const;
+	float value_stamp(unsigned short iChannel, unsigned long iStamp) const;
 
 	// Batch processors.
 	void process(float **ppFrames,
@@ -52,8 +52,8 @@ public:
 	void process_meter(float **ppFrames,
 		unsigned int iFrames, unsigned short iChannels = 0);
 
-    // Reset channel gain trackers.
-    void reset();
+	// Reset channel gain trackers.
+	void reset();
 
 protected:
 
@@ -64,7 +64,9 @@ private:
 
 	// Instance variables.
 	unsigned short m_iChannels;
+	unsigned long *m_piStamps;
 	float         *m_pfValues;
+	float         *m_pfPrevValues;
 	float         *m_pfGains;
 	float         *m_pfPrevGains;
 	volatile int   m_iProcessRamp;
