@@ -1,7 +1,7 @@
 // qtractorCurveFile.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -30,6 +30,8 @@
 
 #include "qtractorMessageList.h"
 
+#include "qtractorSession.h"
+
 #include <QDomDocument>
 #include <QDir>
 
@@ -188,10 +190,12 @@ void qtractorCurveFile::save ( qtractorDocument *pDocument,
 		delete ppSeqs[iSeq];
 	delete [] ppSeqs;
 
-	const QString& sFilename
-		= QDir(m_sBaseDir).relativeFilePath(m_sFilename);
-	pDocument->saveTextElement("filename",
-		pDocument->addFile(sFilename), pElement);
+	QString sFilename;
+	if (pDocument->isArchive())
+		sFilename = pDocument->addFile(m_sFilename);
+	else
+		sFilename = QDir(m_sBaseDir).relativeFilePath(m_sFilename);
+	pDocument->saveTextElement("filename", sFilename, pElement);
 
 	if (iCurrent >= 0) {
 		pDocument->saveTextElement("current",
@@ -205,7 +209,12 @@ void qtractorCurveFile::apply ( qtractorTimeScale *pTimeScale )
 	if (m_pCurveList == NULL)
 		return;
 
-	const QString& sFilename = QDir(m_sBaseDir).absoluteFilePath(m_sFilename);
+	qtractorSession *pSession = qtractorSession::getInstance();
+	if (pSession == NULL)
+		return;
+
+	const QString& sFilename
+		= QDir(m_sBaseDir).absoluteFilePath(m_sFilename);
 
 	qtractorMidiFile file;
 	if (!file.open(sFilename, qtractorMidiFile::Read)) {
@@ -216,6 +225,10 @@ void qtractorCurveFile::apply ( qtractorTimeScale *pTimeScale )
 		return;
 	}
 
+	// Transient curve-file registry method as far to
+	// avoid duplicates across load/save/record cycles...
+	pSession->acquireFilePath(sFilename);
+
 	const unsigned short iTicksPerBeat = pTimeScale->ticksPerBeat();
 	unsigned short iSeq = 0;
 
