@@ -33,6 +33,7 @@ class qtractorSyncEvent;
 class qtractorTracks;
 class qtractorThumbView;
 class qtractorMessageList;
+class qtractorFileSystem;
 class qtractorFiles;
 class qtractorMessages;
 class qtractorConnections;
@@ -50,6 +51,7 @@ class qtractorMidiEditorForm;
 class qtractorMidiEditor;
 class qtractorMidiManager;
 
+class qtractorAudioFileFactory;
 class qtractorPluginFactory;
 
 class qtractorActionControl;
@@ -86,6 +88,7 @@ public:
 	void setup(qtractorOptions *pOptions);
 
 	qtractorTracks *tracks() const;
+	qtractorFileSystem *fileSystem() const;
 	qtractorFiles *files() const;
 	qtractorConnections *connections() const;
 	qtractorMixer *mixer() const;
@@ -234,6 +237,7 @@ public slots:
 	void viewToolbarTransport(bool bOn);
 	void viewToolbarTime(bool bOn);
 	void viewToolbarThumb(bool bOn);
+	void viewFileSystem(bool bOn);
 	void viewFiles(bool bOn);
 	void viewMessages(bool bOn);
 	void viewConnections(bool bOn);
@@ -292,11 +296,12 @@ public slots:
 
 protected slots:
 
-	void timerSlot();
+	void fastTimerSlot();
+	void slowTimerSlot();
 
-	void peakNotify();
 	void alsaNotify();
 
+	void audioPeakNotify();
 	void audioShutNotify();
 	void audioXrunNotify();
 	void audioPortNotify();
@@ -329,6 +334,8 @@ protected slots:
 	void selectMidiFile(const QString& sFilename, int iTrackChannel, bool bSelect);
 	void activateMidiFile(const QString& sFilename, int iTrackChannel = -1);
 
+	void activateFile(const QString& sFilename);
+
 	void trackSelectionChanged();
 	void mixerSelectionChanged();
 
@@ -340,8 +347,6 @@ protected slots:
 		unsigned short iBeatsPerBar, unsigned short iBeatDivisor);
 	void transportTempoFinished();
 
-	void updateTransportLater();
-
 	void snapPerBeatChanged(int iSnap);
 	void contentsChanged();
 
@@ -449,12 +454,14 @@ private:
 	// Instance variables...
 	qtractorOptions *m_pOptions;
 	qtractorSession *m_pSession;
+	qtractorFileSystem *m_pFileSystem;
 	qtractorFiles *m_pFiles;
 	qtractorMessages *m_pMessages;
 	qtractorConnections *m_pConnections;
 	qtractorMixer *m_pMixer;
 	qtractorTracks *m_pTracks;
 	qtractorMessageList *m_pMessageList;
+	qtractorAudioFileFactory *m_pAudioFileFactory;
 	qtractorPluginFactory *m_pPluginFactory;
 	QString m_sFilename;
 	int m_iUntitled;
@@ -480,10 +487,6 @@ private:
 	QString m_sNsmExt;
 	bool m_bNsmDirty;
 	unsigned long m_iPlayHead;
-	int m_iPeakTimer;
-	int m_iPlayTimer;
-	int m_iIdleTimer;
-	int m_iTransportTimer;
 	int m_iTransportUpdate;
 	int m_iTransportRolling;
 	bool m_bTransportPlaying;
@@ -492,6 +495,7 @@ private:
 	int m_iXrunCount;
 	int m_iXrunSkip;
 	int m_iXrunTimer;
+	int m_iAudioPeakTimer;
 	int m_iAudioRefreshTimer;
 	int m_iMidiRefreshTimer;
 	int m_iPlayerTimer;
