@@ -1,7 +1,7 @@
 // qtractorMessages.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@
 #include <QDateTime>
 #include <QIcon>
 
-#if !defined(WIN32)
+#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 #include <unistd.h>
 #include <fcntl.h>
 #endif
@@ -143,7 +143,7 @@ void qtractorMessages::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
 // Set stdout/stderr blocking mode.
 bool qtractorMessages::stdoutBlock ( int fd, bool bBlock ) const
 {
-#if !defined(WIN32)
+#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 	const int iFlags = ::fcntl(fd, F_GETFL, 0);
 	const bool bNonBlock = bool(iFlags & O_NONBLOCK);
 	if (bBlock && bNonBlock)
@@ -159,7 +159,7 @@ bool qtractorMessages::stdoutBlock ( int fd, bool bBlock ) const
 // Own stdout/stderr socket notifier slot.
 void qtractorMessages::stdoutNotify ( int fd )
 {
-#if !defined(WIN32)
+#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 	// Set non-blocking reads, if not already...
 	const bool bBlock = stdoutBlock(fd, false);
 	// Read as much as is available...
@@ -221,7 +221,7 @@ void qtractorMessages::setCaptureEnabled ( bool bCapture )
 	bCapture = false;
 #endif
 
-#if !defined(WIN32)
+#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 	// Destroy if already enabled.
 	if (!bCapture && m_pStdoutNotifier) {
 		delete m_pStdoutNotifier;
