@@ -1,7 +1,7 @@
 // qtractorMidiEditList.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -160,7 +160,7 @@ void qtractorMidiEditList::updatePixmap ( int /*cx*/, int cy )
 	const QPalette& pal = qtractorScrollView::palette();
 
 	const QColor& rgbLine   = pal.mid().color();
-	const QColor& rgbLight  = pal.midlight().color();
+	const QColor& rgbLight  = pal.light().color();
 	const QColor& rgbShadow = pal.shadow().color();
 
 	m_pixmap = QPixmap(w, h);
