@@ -1,7 +1,7 @@
 // qtractorMidiEngine.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -345,6 +345,8 @@ private:
 	unsigned long m_iTimeStartEx;
 	unsigned long m_iFrameStartEx;
 
+	unsigned long m_iAudioFrameStart;
+
 	// The assigned control buses.
 	bool             m_bControlBus;
 	qtractorMidiBus *m_pIControlBus;
@@ -492,14 +494,6 @@ public:
 	qtractorPluginList *pluginList_in()  const;
 	qtractorPluginList *pluginList_out() const;
 
-	// Automation curve list accessors.
-	qtractorCurveList *curveList_in()  const;
-	qtractorCurveList *curveList_out() const;
-
-	// Automation curve serializer accessors.
-	qtractorCurveFile *curveFile_in()  const;
-	qtractorCurveFile *curveFile_out() const;
-
 	// Retrieve/restore client:port connections.
 	// return the effective number of connection attempts.
 	int updateConnects(BusMode busMode,
@@ -560,10 +554,6 @@ private:
 	qtractorPluginList *m_pIPluginList;
 	qtractorPluginList *m_pOPluginList;
 
-	// Automation curve serializer instances.
-	qtractorCurveFile  *m_pICurveFile;
-	qtractorCurveFile  *m_pOCurveFile;
-
 	// SysEx setup list.
 	qtractorMidiSysexList *m_pSysexList;
 
