@@ -1,7 +1,7 @@
 // qtractorMidiListView.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -177,14 +177,17 @@ QStringList qtractorMidiListView::getOpenFileNames (void)
 	QStringList files;
 
 	const QString  sExt("mid");
-	const QString& sTitle  = tr("Open MIDI Files") + " - " QTRACTOR_TITLE;
-	const QString& sFilter = tr("MIDI files (*.%1 *.smf *.midi)").arg(sExt);
-#if 1//QT_VERSION < 0x040400
-	// Ask for the filenames to open...
+	const QString& sTitle
+		= tr("Open MIDI Files") + " - " QTRACTOR_TITLE;
+	const QString& sFilter
+		= tr("MIDI files (*.%1 *.smf *.midi)").arg(sExt);
+
 	QFileDialog::Options options = 0;
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions && pOptions->bDontUseNativeDialogs)
 		options |= QFileDialog::DontUseNativeDialog;
+#if 1//QT_VERSION < 0x040400
+	// Ask for the filenames to open...
 	files = QFileDialog::getOpenFileNames(this,
 		sTitle, recentDir(), sFilter, NULL, options);
 #else
@@ -196,15 +199,13 @@ QStringList qtractorMidiListView::getOpenFileNames (void)
 	fileDialog.setFileMode(QFileDialog::ExistingFiles);
 	fileDialog.setDefaultSuffix(sExt);
 	// Stuff sidebar...
-	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions) {
 		QList<QUrl> urls(fileDialog.sidebarUrls());
 		urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 		urls.append(QUrl::fromLocalFile(pOptions->sMidiDir));
 		fileDialog.setSidebarUrls(urls);
-		if (pOptions->bDontUseNativeDialogs)
-			fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	}
+	fileDialog.setOptions(options);
 	// Show dialog...
 	if (fileDialog.exec())
 		files = fileDialog.selectedFiles();
