@@ -1,7 +1,7 @@
 // qtractorOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -233,7 +233,12 @@ void qtractorOptions::loadOptions (void)
 	bAudioOutputBus = m_settings.value("/AudioOutputBus", false).toBool();
 	bAudioOutputAutoConnect = m_settings.value("/AudioOutputAutoConnect", true).toBool();
 	bOpenEditor = m_settings.value("/OpenEditor", true).toBool();
-	bDummyVstScan = m_settings.value("/DummyVstScan", true).toBool();
+	bQueryEditorType = m_settings.value("/QueryEditorType", false).toBool();
+	bDummyPluginScan = m_settings.value("/DummyPluginScan", true).toBool();
+	iDummyLadspaHash = m_settings.value("/DummyLadspaHash", 0).toInt();
+	iDummyDssiHash = m_settings.value("/DummyDssiHash", 0).toInt();
+	iDummyVstHash = m_settings.value("/DummyVstHash", 0).toInt();
+	iDummyLv2Hash = m_settings.value("/DummyLv2Hash", 0).toInt();
 	bLv2DynManifest = m_settings.value("/Lv2DynManifest", false).toBool();
 	bSaveCurve14bit = m_settings.value("/SaveCurve14bit", false).toBool();
 	m_settings.endGroup();
@@ -286,6 +291,7 @@ void qtractorOptions::loadOptions (void)
 	bTrackViewSnapGrid   = m_settings.value("/TrackViewSnapGrid", true).toBool();
 	bTrackViewToolTips   = m_settings.value("/TrackViewToolTips", true).toBool();
 	bTrackViewCurveEdit  = m_settings.value("/TrackViewCurveEdit", false).toBool();
+	bTrackListMeters     = m_settings.value("/TrackListMeters", false).toBool();
 	m_settings.endGroup();
 
 	// MIDI options group.
@@ -344,7 +350,7 @@ void qtractorOptions::loadOptions (void)
 
 	// Run-time special semi/non-persistent options.
 	m_settings.beginGroup("/Dialogs");
-	bUseNativeDialogs = m_settings.value("/UseNativeDialogs", true).toBool();
+	bUseNativeDialogs = m_settings.value("/UseNativeDialogs", false).toBool();
 	bDontUseNativeDialogs = !bUseNativeDialogs;
 	m_settings.endGroup();
 
@@ -521,7 +527,12 @@ void qtractorOptions::saveOptions (void)
 	m_settings.setValue("/AudioOutputBus", bAudioOutputBus);
 	m_settings.setValue("/AudioOutputAutoConnect", bAudioOutputAutoConnect);
 	m_settings.setValue("/OpenEditor", bOpenEditor);
-	m_settings.setValue("/DummyVstScan", bDummyVstScan);
+	m_settings.setValue("/QueryEditorType", bQueryEditorType);
+	m_settings.setValue("/DummyPluginScan", bDummyPluginScan);
+	m_settings.setValue("/DummyLadspaHash", iDummyLadspaHash);
+	m_settings.setValue("/DummyDssiHash", iDummyDssiHash);
+	m_settings.setValue("/DummyVstHash", iDummyVstHash);
+	m_settings.setValue("/DummyLv2Hash", iDummyLv2Hash);
 	m_settings.setValue("/Lv2DynManifest", bLv2DynManifest);
 	m_settings.setValue("/SaveCurve14bit", bSaveCurve14bit);
 	m_settings.endGroup();
@@ -565,6 +576,7 @@ void qtractorOptions::saveOptions (void)
 	m_settings.setValue("/TrackViewSnapGrid", bTrackViewSnapGrid);
 	m_settings.setValue("/TrackViewToolTips", bTrackViewToolTips);
 	m_settings.setValue("/TrackViewCurveEdit", bTrackViewCurveEdit);
+	m_settings.setValue("/TrackListMeters", bTrackListMeters);
 	m_settings.endGroup();
 
 	// MIDI Editor options group.
@@ -722,12 +734,11 @@ bool qtractorOptions::parse_args ( const QStringList& args )
 			return false;
 		}
 		else if (sArg == "-v" || sArg == "--version") {
-			out << QObject::tr("Qt: %1\n")
+			out << QString("Qt: %1\n")
 				.arg(qVersion());
-			out << QObject::tr("%1: %2  (%3)\n")
+			out << QString("%1: %2\n")
 				.arg(QTRACTOR_TITLE)
-				.arg(CONFIG_BUILD_VERSION)
-				.arg(CONFIG_BUILD_DATE);
+				.arg(CONFIG_BUILD_VERSION);
 			return false;
 		}
 		else {
@@ -757,7 +768,6 @@ void qtractorOptions::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 			= m_settings.value("/geometry").toByteArray();
 		if (!geometry.isEmpty())
 			pWidget->restoreGeometry(geometry);
-		else
 	#else//--LOAD_OLD_GEOMETRY
 		QPoint wpos;
 		QSize  wsize;
@@ -769,9 +779,9 @@ void qtractorOptions::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 			pWidget->move(wpos);
 		if (wsize.width() > 0 && wsize.height() > 0)
 			pWidget->resize(wsize);
-		else
 	#endif
-		pWidget->adjustSize();
+	//	else
+	//	pWidget->adjustSize();
 		if (!bVisible)
 			bVisible = m_settings.value("/visible", false).toBool();
 		if (bVisible)
@@ -1067,3 +1077,4 @@ void qtractorOptions::saveActionControl ( QObject *pObject )
 
 
 // end of qtractorOptions.cpp
+
