@@ -1,7 +1,7 @@
 // qtractorPluginFactory.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,10 +25,7 @@
 #include "qtractorPlugin.h"
 
 #include <QProcess>
-
-
-// Forward decls.
-class qtractorPluginFactoryProxy;
+#include <QFile>
 
 
 //----------------------------------------------------------------------------
@@ -62,11 +59,13 @@ public:
 	// Plugin types registry.
 	typedef QList<qtractorPluginType *> Types;
 	const Types& types() const { return m_types; }
+
 	// Type register method.
 	void addType(qtractorPluginType *pType) { m_types.append(pType); }
 
-	// Type list reset method.
+	// Type list reset methods.
 	void clear();
+	void clearAll();
 
 	// Global plugin-paths executive methods.
 	QStringList pluginPaths(qtractorPluginType::Hint typeHint);
@@ -92,8 +91,14 @@ protected:
 	int addFiles(qtractorPluginType::Hint typeHint, const QStringList& paths);
 	int addFiles(qtractorPluginType::Hint typeHint, const QString& sPath);
 
-	// Plugin type listing.
-	bool addTypes(qtractorPluginType::Hint typeHint, const QString& sFilename);
+	// Plugin type listing methods.
+	bool addTypes(qtractorPluginType::Hint typeHint,
+		const QString& sFilename);
+	bool addTypes(qtractorPluginType::Hint typeHint,
+		qtractorPluginFile *pFile, unsigned long iIndex);
+
+	// Generic plugin-scan factory method.
+	bool startScan(qtractorPluginType::Hint typeHint);
 
 	// Plugin scan reset method.
 	void reset();
@@ -112,8 +117,15 @@ private:
 	// Internal plugin types list.
 	Types m_types;
 
-	// Proxy (out-of-process) client.
-	qtractorPluginFactoryProxy *m_pProxy;
+	// Scan (out-of-process) clients.
+	class Scanner;
+
+	typedef QHash<qtractorPluginType::Hint, Scanner *> Scanners;
+
+	Scanners m_scanners;
+
+	// List of active cache scan results.
+	QStringList m_cacheFilePaths;
 
 	// Pseudo-singleton instance.
 	static qtractorPluginFactory *g_pPluginFactory;
@@ -121,29 +133,57 @@ private:
 
 
 //----------------------------------------------------------------------------
-// qtractorPluginFactoryProxy -- Plugin path proxy (out-of-process client).
+// qtractorPluginFactory::Scanner -- Plugin scan proxy (out-of-process client).
 //
 
-class qtractorPluginFactoryProxy : public QProcess
+class qtractorPluginFactory::Scanner : public QProcess
 {
 	Q_OBJECT
 
 public:
 
 	// ctor.
-	qtractorPluginFactoryProxy(qtractorPluginFactory *pPluginFactory);
+	Scanner(qtractorPluginType::Hint typeHint, QObject *pParent = NULL);
 
-	// Start method.
-	bool start();
+	// Open/close method.
+	bool open(bool bReset = false);
+	void close();
 
 	// Service methods.
 	bool addTypes(qtractorPluginType::Hint typeHint, const QString& sFilename);
 
+	// Absolute cache file path.
+	QString cacheFilePath() const;
+
 protected slots:
 
 	// Service slots.
 	void stdout_slot();
 	void stderr_slot();
+
+	void exit_slot(int exitCode, QProcess::ExitStatus exitStatus);
+
+protected:
+
+	// Scan start method.
+	bool start();
+
+	// Service methods (internal)
+	bool addTypes(const QStringList& list);
+
+private:
+
+	// Instance scanner name.
+	qtractorPluginType::Hint m_typeHint;
+
+	// Instance state.
+	volatile int m_iExitStatus;
+
+	// Cache file object.
+	QFile m_file;
+
+	// Cache hash list.
+	QHash<QString, QStringList> m_list;
 };
 
 
