@@ -1,7 +1,7 @@
 // qtractorPluginListView.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -285,8 +285,6 @@ void qtractorPluginListItem::updateActivated (void)
 int    qtractorPluginListView::g_iItemRefCount = 0;
 QIcon *qtractorPluginListView::g_pItemIcons[2] = { NULL, NULL };
 
-qtractorPluginListView::TinyScrollBarStyle *g_pTinyScrollBarStyle = NULL;
-
 // Construcctor.
 qtractorPluginListView::qtractorPluginListView ( QWidget *pParent )
 	: QListWidget(pParent), m_pPluginList(NULL), m_pClickedItem(NULL)
@@ -398,12 +396,6 @@ void qtractorPluginListView::setTinyScrollBar ( bool bTinyScrollBar )
 	}
 }
 
-bool qtractorPluginListView::isTinyScrollBar (void) const
-{
-	return QListWidget::verticalScrollBar()->style()   == g_pTinyScrollBarStyle
-		&& QListWidget::horizontalScrollBar()->style() == g_pTinyScrollBarStyle;
-}
-
 
 // Plugin list refreshner
 void qtractorPluginListView::refresh (void)
