@@ -1,7 +1,7 @@
 // qtractorRingBuffer.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -93,24 +93,18 @@ qtractorRingBuffer<T>::qtractorRingBuffer ( unsigned short iChannels,
 {
 	m_iChannels = iChannels;
 
-	// Buffer size range.
+	// Adjust buffer size of nearest power-of-two, if necessary.
 	const unsigned int iMinBufferSize = 4096;
-	const unsigned int iMaxBufferSize = 4096 * 32;
+	m_iBufferSize = iMinBufferSize;
+	while (m_iBufferSize < iBufferSize)
+		m_iBufferSize <<= 1;
 
-	// Adjust size of nearest power-of-two, if necessary.
-	if (iBufferSize < iMaxBufferSize) {
-		m_iBufferSize = iMinBufferSize;
-		while (m_iBufferSize < iBufferSize)
-			m_iBufferSize <<= 1;
-	} else {
-		m_iBufferSize = iMaxBufferSize;
-	}
 	// The size overflow convenience mask and tthreshold.
 	m_iBufferMask = (m_iBufferSize - 1);
 
 	// Allocate actual buffer stuff...
 	m_ppBuffer = new T* [m_iChannels];
-	for (unsigned short i = 0; i < m_iChannels; i++)
+	for (unsigned short i = 0; i < m_iChannels; ++i)
 		m_ppBuffer[i] = new T [m_iBufferSize];
 
 	ATOMIC_SET(&m_iReadIndex,  0);
@@ -123,7 +117,7 @@ qtractorRingBuffer<T>::~qtractorRingBuffer (void)
 {
 	// Deallocate any buffer stuff...
 	if (m_ppBuffer) {
-		for (unsigned short i = 0; i < m_iChannels; i++)
+		for (unsigned short i = 0; i < m_iChannels; ++i)
 			delete [] m_ppBuffer[i];
 		delete [] m_ppBuffer;
 	}
@@ -180,7 +174,7 @@ int qtractorRingBuffer<T>::read ( T **ppFrames, unsigned int iFrames,
 		n2 = 0;
 	}
 
-	for (unsigned short i = 0; i < m_iChannels; i++) {
+	for (unsigned short i = 0; i < m_iChannels; ++i) {
 		::memcpy((T *)(ppFrames[i] + iOffset),
 			(T *)(m_ppBuffer[i] + r), n1 * sizeof(T));
 		if (n2) {
@@ -219,7 +213,7 @@ int qtractorRingBuffer<T>::write ( T **ppFrames, unsigned int iFrames,
 		n2 = 0;
 	}
 
-	for (unsigned short i = 0; i < m_iChannels; i++) {
+	for (unsigned short i = 0; i < m_iChannels; ++i) {
 		::memcpy((T *)(m_ppBuffer[i] + w),
 			(T *)(ppFrames[i] + iOffset), n1 * sizeof(T));
 		if (n2 > 0) {
