@@ -1,7 +1,7 @@
 // qtractorTimeScaleCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -72,36 +72,37 @@ bool qtractorTimeScaleNodeCommand::addNode (void)
 	if (pSession == NULL)
 		return false;
 
+	qtractorTimeScale::Cursor& cursor = m_pTimeScale->cursor();
+	qtractorTimeScale::Node *pNode = cursor.seekFrame(m_iFrame);
+	if (pNode == NULL)
+		return false;
+
 	// If currently playing, we need to do a stop and go...
 	const bool bPlaying = pSession->isPlaying();
-	if (bPlaying)
-		pSession->lock();
 
-	qtractorTimeScale::Node *pNode = m_pTimeScale->addNode(
-		m_iFrame, m_fTempo, m_iBeatType, m_iBeatsPerBar, m_iBeatDivisor);
+	pSession->lock();
 
-	qtractorTimeScale::Node *pPrev = pNode->prev();
-	const float fOldTempo = (pPrev ? pPrev->tempo : m_pTimeScale->tempo());
-	const float fNewTempo = pNode->tempo;
+	const float fOldTempo = pNode->tempo;
+	const float fNewTempo = m_fTempo;
 
 	const bool bRedoClipCommand = (m_pClipCommand == NULL);
-	if (bRedoClipCommand) {
+	if (bRedoClipCommand)
 		m_pClipCommand = createClipCommand(pNode, fNewTempo, fOldTempo);
-		if (m_pClipCommand)
-			m_pClipCommand->redo();
-	} else {
+	else
+	if (m_pClipCommand) {
 		m_pClipCommand->undo();
 		delete m_pClipCommand;
 		m_pClipCommand = NULL;
 	}
 
+	pNode = m_pTimeScale->addNode(
+		m_iFrame, m_fTempo, m_iBeatType, m_iBeatsPerBar, m_iBeatDivisor);
+
 	const bool bRedoCurveEditCommands = m_curveEditCommands.isEmpty();
 	if (bRedoCurveEditCommands) {
 		addCurveEditCommands(pNode, fNewTempo, fOldTempo);
-		QListIterator<qtractorCurveEditCommand *> redos(m_curveEditCommands);
-		while (redos.hasNext())
-			redos.next()->redo();
 	} else {
+
 		QListIterator<qtractorCurveEditCommand *> undos(m_curveEditCommands);
 		while (undos.hasNext())
 			undos.next()->undo();
@@ -109,6 +110,15 @@ bool qtractorTimeScaleNodeCommand::addNode (void)
 		m_curveEditCommands.clear();
 	}
 
+	if (m_pClipCommand && bRedoClipCommand)
+		m_pClipCommand->redo();
+
+	if (bRedoCurveEditCommands) {
+		QListIterator<qtractorCurveEditCommand *> redos(m_curveEditCommands);
+		while (redos.hasNext())
+			redos.next()->redo();
+	}
+
 	// Restore playback state, if needed...
 	if (bPlaying) {
 		// The Audio engine too...
@@ -117,9 +127,14 @@ bool qtractorTimeScaleNodeCommand::addNode (void)
 		// The MIDI engine queue needs a reset...
 		if (pSession->midiEngine())
 			pSession->midiEngine()->resetTempo();
-		pSession->unlock();
+	} else {
+		// Force JACK Timebase state, if applicable...
+		if (pSession->audioEngine())
+			pSession->audioEngine()->resetTimebase();
 	}
 
+	pSession->unlock();
+
 	return true;
 }
 
@@ -140,8 +155,8 @@ bool qtractorTimeScaleNodeCommand::updateNode (void)
 
 	// If currently playing, we need to do a stop and go...
 	const bool bPlaying = pSession->isPlaying();
-	if (bPlaying)
-		pSession->lock();
+
+	pSession->lock();
 
 	const float          fTempo       = pNode->tempo;
 	const unsigned short iBeatType    = pNode->beatType;
@@ -154,10 +169,23 @@ bool qtractorTimeScaleNodeCommand::updateNode (void)
 	const bool bRedoClipCommand = (m_pClipCommand == NULL);
 	if (bRedoClipCommand)
 		m_pClipCommand = createClipCommand(pNode, fNewTempo, fOldTempo);
+	else
+	if (m_pClipCommand) {
+		m_pClipCommand->undo();
+		delete m_pClipCommand;
+		m_pClipCommand = NULL;
+	}
 
 	const bool bRedoCurveEditCommands = m_curveEditCommands.isEmpty();
-	if (bRedoCurveEditCommands)
+	if (bRedoCurveEditCommands) {
 		addCurveEditCommands(pNode, fNewTempo, fOldTempo);
+	} else {
+		QListIterator<qtractorCurveEditCommand *> undos(m_curveEditCommands);
+		while (undos.hasNext())
+			undos.next()->undo();
+		qDeleteAll(m_curveEditCommands);
+		m_curveEditCommands.clear();
+	}
 
 	pNode->tempo       = m_fTempo;
 	pNode->beatType    = m_iBeatType;
@@ -171,26 +199,13 @@ bool qtractorTimeScaleNodeCommand::updateNode (void)
 	m_iBeatsPerBar = iBeatsPerBar;
 	m_iBeatDivisor = iBeatDivisor;
 
-	if (m_pClipCommand) {
-		if (bRedoClipCommand) {
-			m_pClipCommand->redo();
-		} else {
-			m_pClipCommand->undo();
-			delete m_pClipCommand;
-			m_pClipCommand = NULL;
-		}
-	}
+	if (m_pClipCommand && bRedoClipCommand)
+		m_pClipCommand->redo();
 
 	if (bRedoCurveEditCommands) {
 		QListIterator<qtractorCurveEditCommand *> redos(m_curveEditCommands);
 		while (redos.hasNext())
 			redos.next()->redo();
-	} else {
-		QListIterator<qtractorCurveEditCommand *> undos(m_curveEditCommands);
-		while (undos.hasNext())
-			undos.next()->undo();
-		qDeleteAll(m_curveEditCommands);
-		m_curveEditCommands.clear();
 	}
 
 	// Restore playback state, if needed...
@@ -201,9 +216,14 @@ bool qtractorTimeScaleNodeCommand::updateNode (void)
 		// The MIDI engine queue needs a reset...
 		if (pSession->midiEngine())
 			pSession->midiEngine()->resetTempo();
-		pSession->unlock();
+	} else {
+		// Force JACK Timebase state, if applicable...
+		if (pSession->audioEngine())
+			pSession->audioEngine()->resetTimebase();
 	}
 
+	pSession->unlock();
+
 	return true;
 }
 
@@ -224,8 +244,8 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 
 	// If currently playing, we need to do a stop and go...
 	const bool bPlaying = pSession->isPlaying();
-	if (bPlaying)
-		pSession->lock();
+
+	pSession->lock();
 
 	qtractorTimeScale::Node *pPrev = pNode->prev();
 	const float fOldTempo = pNode->tempo;
@@ -234,12 +254,25 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 	const bool bRedoClipCommand = (m_pClipCommand == NULL);
 	if (bRedoClipCommand)
 		m_pClipCommand = createClipCommand(pNode, fNewTempo, fOldTempo);
+	else
+	if (m_pClipCommand) {
+		m_pClipCommand->undo();
+		delete m_pClipCommand;
+		m_pClipCommand = NULL;
+	}
 
 	const bool bRedoCurveEditCommands = m_curveEditCommands.isEmpty();
-	if (bRedoCurveEditCommands)
+	if (bRedoCurveEditCommands) {
 		addCurveEditCommands(pNode, fNewTempo, fOldTempo);
+	} else {
+
+		QListIterator<qtractorCurveEditCommand *> undos(m_curveEditCommands);
+		while (undos.hasNext())
+			undos.next()->undo();
+		qDeleteAll(m_curveEditCommands);
+		m_curveEditCommands.clear();
+	}
 
-//	m_iFrame       = pNode->frame;
 	m_fTempo       = pNode->tempo;
 	m_iBeatType    = pNode->beatType;
 	m_iBeatsPerBar = pNode->beatsPerBar;
@@ -247,26 +280,13 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 
 	m_pTimeScale->removeNode(pNode);
 
-	if (m_pClipCommand) {
-		if (bRedoClipCommand) {
-			m_pClipCommand->redo();
-		} else {
-			m_pClipCommand->undo();
-			delete m_pClipCommand;
-			m_pClipCommand = NULL;
-		}
-	}
+	if (m_pClipCommand && bRedoClipCommand)
+		m_pClipCommand->redo();
 
 	if (bRedoCurveEditCommands) {
 		QListIterator<qtractorCurveEditCommand *> redos(m_curveEditCommands);
 		while (redos.hasNext())
 			redos.next()->redo();
-	} else {
-		QListIterator<qtractorCurveEditCommand *> undos(m_curveEditCommands);
-		while (undos.hasNext())
-			undos.next()->undo();
-		qDeleteAll(m_curveEditCommands);
-		m_curveEditCommands.clear();
 	}
 
 	// Restore playback state, if needed...
@@ -277,9 +297,14 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 		// The MIDI engine queue needs a reset...
 		if (pSession->midiEngine())
 			pSession->midiEngine()->resetTempo();
-		pSession->unlock();
+	} else {
+		// Force JACK Timebase state, if applicable...
+		if (pSession->audioEngine())
+			pSession->audioEngine()->resetTimebase();
 	}
 
+	pSession->unlock();
+
 	return true;
 }
 
