@@ -901,9 +901,14 @@ void qtractorTimeScaleForm::markerColor (void)
 
 	QPalette pal(m_ui.MarkerTextLineEdit->palette());
 
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	QColorDialog::ColorDialogOptions options = 0;
+	if (pOptions && pOptions->bDontUseNativeDialogs)
+		options |= QColorDialog::DontUseNativeDialog;
+
 	const QColor& color	= QColorDialog::getColor(
 		pal.text().color(), this,
-		tr("Marker Color") + " - " QTRACTOR_TITLE);
+		tr("Marker Color") + " - " QTRACTOR_TITLE, options);
 
 	if (color.isValid()) {
 		pal.setColor(QPalette::Text, color);
