@@ -1,7 +1,7 @@
 // qtractorTimeStretch.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    Adapted and refactored from the SoundTouch library (L)GPL,
    Copyright (C) 2001-2012, Olli Parviainen.
@@ -527,7 +527,7 @@ void qtractorTimeStretch::flushInput (void)
 		// Push the last active frames out from the pipeline
 		// by feeding blank samples into processing until
 		// new samples appear in the output...
-		unsigned int iFrames = frames();
+		const unsigned int iFrames = frames();
 		for (i = 0; i < 128; ++i) {
 			putFrames(m_ppFrames, 256);
 			// Any new samples appeared in the output?
@@ -549,7 +549,7 @@ void qtractorTimeStretch::flushInput (void)
 void qtractorTimeStretch::calcCrossCorrReference (void)
 {
 	for (unsigned int j = 0 ; j < m_iOverlapLength ; ++j) {
-		float fTemp = (float) j * (float) (m_iOverlapLength - j);
+		const float fTemp = (float) j * (float) (m_iOverlapLength - j);
 		for (unsigned short i = 0; i < m_iChannels; ++i)
 			m_ppRefMidBuffer[i][j] = (float) (m_ppMidBuffer[i][j] * fTemp);
 	}
@@ -565,7 +565,7 @@ void qtractorTimeStretch::calcOverlapLength (void)
 		iNewOverlapLength = 16;
 	iNewOverlapLength -= (iNewOverlapLength % 8);
 
-	unsigned int iOldOverlapLength = m_iOverlapLength;
+	const unsigned int iOldOverlapLength = m_iOverlapLength;
 	m_iOverlapLength = iNewOverlapLength;
 	if (m_iOverlapLength > iOldOverlapLength) {
 		unsigned short i;
