@@ -1,7 +1,7 @@
 // qtractorTimeStretcher.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -29,21 +29,29 @@
 // Constructor.
 qtractorTimeStretcher::qtractorTimeStretcher (
 	unsigned short iChannels, unsigned int iSampleRate,
-	float fTimeStretch, float fPitchShift, unsigned int iFlags )
+	float fTimeStretch, float fPitchShift,
+	unsigned int iFlags, unsigned int iBufferSize )
 	: m_pTimeStretch(NULL)
 #ifdef CONFIG_LIBRUBBERBAND
 	, m_pRubberBandStretcher(NULL)
 	, m_iRubberBandChannels(iChannels)
+	, m_iRubberBandLatency(0)
+	, m_iRubberBandFrames(0)
 	, m_ppRubberBandFrames(NULL)
+	, m_ppRubberBandBuffer(NULL)
 	, m_bRubberBandFlush(false)
 #endif
 {
-	if (fTimeStretch > 0.0f && (iFlags & WsolaTimeStretch)) {
-		m_pTimeStretch = new qtractorTimeStretch(iChannels, iSampleRate);
-		m_pTimeStretch->setTempo(1.0f / fTimeStretch);
-		m_pTimeStretch->setQuickSeek(iFlags & WsolaQuickSeek);
-		fTimeStretch = 0.0f;
+	if ((fTimeStretch > 0.1f && fTimeStretch < 1.0f - 1e-3f) ||
+		(fTimeStretch > 1.0f + 1e-3f && fTimeStretch < 4.0f)) {
+		if (iFlags & WsolaTimeStretch) {
+			m_pTimeStretch = new qtractorTimeStretch(iChannels, iSampleRate);
+			m_pTimeStretch->setTempo(1.0f / fTimeStretch);
+			m_pTimeStretch->setQuickSeek(iFlags & WsolaQuickSeek);
+			fTimeStretch = 0.0f;
+		}
 	}
+	else fTimeStretch = 0.0f;
 #ifdef CONFIG_LIBRUBBERBAND
 	if (fTimeStretch > 0.0f ||
 		(fPitchShift > 0.1f && fPitchShift < 1.0f - 1e-3f) ||
@@ -55,7 +63,17 @@ qtractorTimeStretcher::qtractorTimeStretcher (
 				iSampleRate, iChannels,
 				RubberBand::RubberBandStretcher::OptionProcessRealTime,
 				fTimeStretch, fPitchShift);
-		m_ppRubberBandFrames = new float * [m_iRubberBandChannels];
+		m_pRubberBandStretcher->setMaxProcessSize(iBufferSize);
+		m_ppRubberBandBuffer = new float * [m_iRubberBandChannels];
+		m_iRubberBandLatency = m_pRubberBandStretcher->getLatency();
+		m_iRubberBandFrames = m_iRubberBandLatency;
+		if (m_iRubberBandFrames > 0) {
+			m_ppRubberBandFrames = new float * [m_iRubberBandChannels];
+			m_ppRubberBandFrames[0] = new float [m_iRubberBandFrames];
+			::memset(m_ppRubberBandFrames[0], 0, m_iRubberBandFrames * sizeof(float));
+			for (unsigned short i = 1; i < m_iRubberBandChannels; ++i)
+				m_ppRubberBandFrames[i] = m_ppRubberBandFrames[0];
+		}
 	}
 #endif
 }
@@ -66,8 +84,12 @@ qtractorTimeStretcher::~qtractorTimeStretcher()
 	if (m_pTimeStretch)
 		delete m_pTimeStretch;
 #ifdef CONFIG_LIBRUBBERBAND
-	if (m_ppRubberBandFrames)
+	if (m_ppRubberBandBuffer)
+		delete [] m_ppRubberBandBuffer;
+	if (m_ppRubberBandFrames) {
+		delete [] m_ppRubberBandFrames[0];
 		delete [] m_ppRubberBandFrames;
+	}
 	if (m_pRubberBandStretcher)
 		delete m_pRubberBandStretcher;
 #endif
@@ -86,9 +108,9 @@ void qtractorTimeStretcher::process (
 			unsigned int nread = iFrames;
 			while (nread > 0 && noffs < iFrames) {
 				for (unsigned short i = 0; i < m_iRubberBandChannels; ++i)
-					m_ppRubberBandFrames[i] = ppFrames[i] + noffs;
+					m_ppRubberBandBuffer[i] = ppFrames[i] + noffs;
 				nread = m_pTimeStretch->receiveFrames(
-					m_ppRubberBandFrames, iFrames - noffs);
+					m_ppRubberBandBuffer, iFrames - noffs);
 				noffs += nread;
 			}
 			iFrames = noffs;
@@ -108,8 +130,24 @@ unsigned int qtractorTimeStretcher::retrieve (
 	float **ppFrames, unsigned int iFrames )
 {
 #ifdef CONFIG_LIBRUBBERBAND
-	if (m_pRubberBandStretcher)
-		return m_pRubberBandStretcher->retrieve(ppFrames, iFrames);
+	if (m_pRubberBandStretcher) {
+		unsigned int nread = m_pRubberBandStretcher->retrieve(ppFrames, iFrames);
+		if (nread > 0 && m_iRubberBandLatency > 0) {
+			if (m_iRubberBandLatency > nread) {
+				m_iRubberBandLatency -= nread;
+				nread = 0;
+			} else {
+				unsigned int noffs = m_iRubberBandLatency;
+				nread -= m_iRubberBandLatency;
+				m_iRubberBandLatency = 0;
+				for (unsigned int i = 0; i < m_iRubberBandChannels; ++i) {
+					float *pFrames = ppFrames[i];
+					::memmove(pFrames, pFrames + noffs, nread * sizeof(float));
+				}
+			}
+		}
+		return nread;
+	}
 #endif
 	return (m_pTimeStretch ? m_pTimeStretch->receiveFrames(ppFrames, iFrames) : 0);
 }
@@ -118,11 +156,17 @@ unsigned int qtractorTimeStretcher::retrieve (
 // Returns number of frames currently available.
 unsigned int qtractorTimeStretcher::available (void) const
 {
+	int iAvailable = 0;
+
 #ifdef CONFIG_LIBRUBBERBAND
 	if (m_pRubberBandStretcher)
-		return m_pRubberBandStretcher->available();
+		iAvailable = m_pRubberBandStretcher->available();
+	else
 #endif
-	return (m_pTimeStretch ? m_pTimeStretch->frames() : 0);
+	if (m_pTimeStretch)
+		iAvailable = m_pTimeStretch->frames();
+
+	return (iAvailable > 0 ? iAvailable : 0);
 }
 
 
@@ -134,12 +178,12 @@ void qtractorTimeStretcher::flush (void)
 		m_pTimeStretch->flushInput();
 #ifdef CONFIG_LIBRUBBERBAND
 	if (m_pRubberBandStretcher && !m_bRubberBandFlush) {
-		// Prepare a dummy empty buffer...
-		float dummy[256];
-		::memset(&dummy[0], 0, sizeof(dummy));
-		for (unsigned short i = 0; i < m_iRubberBandChannels; ++i)
-			m_ppRubberBandFrames[i] = &dummy[0];
-		m_pRubberBandStretcher->process(m_ppRubberBandFrames, 256, true);
+		// Process a last dummy empty buffer...
+		if (m_iRubberBandFrames > 0) {
+			m_pRubberBandStretcher->process(
+				m_ppRubberBandFrames, m_iRubberBandFrames, true);
+		}
+		m_iRubberBandLatency = 0;
 		m_bRubberBandFlush = true;
 	}
 #endif
@@ -154,6 +198,19 @@ void qtractorTimeStretcher::reset (void)
 #ifdef CONFIG_LIBRUBBERBAND
 	if (m_pRubberBandStretcher) {
 		m_pRubberBandStretcher->reset();
+		m_iRubberBandLatency = m_pRubberBandStretcher->getLatency();
+		m_iRubberBandFrames = m_iRubberBandLatency;
+		if (m_iRubberBandFrames > 0) {
+			if (m_ppRubberBandFrames) {
+				delete [] m_ppRubberBandFrames[0];
+			//	delete [] m_ppRubberBandFrames;
+			}
+		//	m_ppRubberBandFrames = new float * [m_iRubberBandChannels];
+			m_ppRubberBandFrames[0] = new float [m_iRubberBandFrames];
+			::memset(m_ppRubberBandFrames[0], 0, m_iRubberBandFrames * sizeof(float));
+			for (unsigned short i = 1; i < m_iRubberBandChannels; ++i)
+				m_ppRubberBandFrames[i] = m_ppRubberBandFrames[0];
+		}
 		m_bRubberBandFlush = false;
 	}
 #endif
