@@ -1,7 +1,7 @@
 // qtractorTrackView.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
 #include "qtractorCurve.h"
 
 #include <QPixmap>
+#include <QBrush>
 
 
 // Forward declarations.
@@ -585,6 +586,10 @@ private:
 	qtractorCurve::Node *m_pEditCurveNode;
 	QDoubleSpinBox      *m_pEditCurveNodeSpinBox;
 	int                  m_iEditCurveNodeDirty;
+
+	// Optional edge-shadow gradient brushes.
+	QBrush m_gradLeft;
+	QBrush m_gradRight;
 };
 
 
